:mod:`djangoflash.middleware` --- Django-flash middleware
=========================================================

.. automodule:: djangoflash.middleware
   :synopsis: Django-flash middleware

:class:`FlashMiddleware` Class
``````````````````````````````

.. autoclass:: FlashMiddleware
   :show-inheritance:

   .. automethod:: get_context_from_request(request)
   .. automethod:: get_context_from_session(request)
   .. automethod:: process_request(request)
   .. automethod:: process_response(request, response)

.. seealso::
   :ref:`modulesindex`
